==> hrflow_connectors-3.2.0.tar.gz: hrflow_connectors-3.2.0/src/hrflow_connectors/connectors/bullhorn/README.md <==
# 📖 Summary
- [📖 Summary](#-summary)
- [💼 About Bullhorn](#-about-bullhorn)
  - [😍 Why is it a big deal for Bullhorn customers \& partners?](#-why-is-it-a-big-deal-for-bullhorn-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [🐍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [🙏 Special Thanks](#-special-thanks)


# 💼 About Bullhorn
Bullhorn is a cloud computing company headquartered in Boston, Massachusetts. The company provides customer relationship management (CRM), applicant tracking system (ATS) and operations software for the staffing industry. As of 2019, the company reported more than 11,000 customers in more than 150 countries. Besides its Boston headquarters, the company has operations in St. Louis, London, Brighton, Sydney and Rotterdam.

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124159-5bf2ff28-66a7-4327-ba1d-e417748d4ab5.png width=90% height=100% >
</p>

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124837-d8dd8f03-dae5-4298-ba57-cef2c00df4dd.png width=90% height=100% >
</p>

## 😍 Why is it a big deal for Bullhorn customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Bullhorn customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Bullhorn customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Bullhorn to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Bullhorn.
- ⬅️ Send Jobs data from Bullhorn to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Bullhorn.

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/9dc5543c-5507-4317-ad23-c1702153a972 width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Bullhorn**)

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/217298819-29d43799-422d-48f4-8995-272d0af66cbe.gif width=90% height=100% >
</p>

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Push profile**](docs/push_profile.md) | Writes a profile from Hrflow.ai Source to Bullhorn via the API |
| [**Pull job list**](docs/pull_job_list.md) | Retrieves jobs from Bullhorn and writes them to Hrflow.ai Board |
| [**Pull resume attachment list**](docs/pull_resume_attachment_list.md) | retrieves profiles attachments from Bullhorn and Parses them and sends them to Hrflow.ai source |
| [**Pull profile list**](docs/pull_profile_list.md) | Retrieves profiles from Bullhorn and writes them to Hrflow.ai source |


</p>|



# 🐍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**. 


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216126235-03319722-c10b-460d-b19d-0e4240fe652c.png width=90% height=100% >
</p>


Once the connector module is imported, you can leverage all the different actions that it offers. 

For more code details checkout connector code 


# 🔗 Useful Links

- 📄Visit [Bullhorn](https://www.bullhorn.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/bullhorn) on our Github.


# 🙏 Special Thanks  
- 💻 HrFlow.ai : [Daniel ROSA](https://github.com/DanielRosa73) - Software Engineer
- 🤝 Bullhorn : Arne LOOTEN - Partner Manager

==> hrflow_connectors-4.23.0.tar.gz: hrflow_connectors-4.23.0/src/hrflow_connectors/connectors/bullhorn/README.md <==
# 📖 Summary
- [📖 Summary](#-summary)
- [💼 About Bullhorn](#-about-bullhorn)
  - [😍 Why is it a big deal for Bullhorn customers \& partners?](#-why-is-it-a-big-deal-for-bullhorn-customers--partners)
- [🔧 How does it work?](#-how-does-it-work)
  - [📊 Data integration capabilities:](#-data-integration-capabilities)
  - [🧠 Artificial Intelligence capabilities:](#-artificial-intelligence-capabilities)
- [🔌 Connector Actions](#-connector-actions)
- [🐍 Quick Start Examples](#-quick-start-examples)
- [🔗 Useful Links](#-useful-links)
- [👏 Special Thanks](#-special-thanks)


# 💼 About Bullhorn
Bullhorn is a cloud computing company headquartered in Boston, Massachusetts. The company provides customer relationship management (CRM), applicant tracking system (ATS) and operations software for the staffing industry. As of 2019, the company reported more than 11,000 customers in more than 150 countries. Besides its Boston headquarters, the company has operations in St. Louis, London, Brighton, Sydney and Rotterdam.

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124159-5bf2ff28-66a7-4327-ba1d-e417748d4ab5.png width=90% height=100% >
</p>

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216124837-d8dd8f03-dae5-4298-ba57-cef2c00df4dd.png width=90% height=100% >
</p>

## 😍 Why is it a big deal for Bullhorn customers & partners?

This new connector will enable:
- ⚡ A Fastlane Talent & Workforce data integration for Bullhorn customers & partners
- 🤖 Cutting-edge AI-powered Talent Experiences & Recruiter Experiences for Bullhorn customers

#  🔧 How does it work?
## 📊 Data integration capabilities:
- ⬅️ Send Profiles data from Bullhorn to a Destination of your choice.
- ➡️ Send Profiles data from a Source of your choice to Bullhorn.
- ⬅️ Send Jobs data from Bullhorn to a Destination of your choice.
- ➡️ Send Jobs data from a Source of your choice to Bullhorn.

<p align="center">
<image src=https://github.com/Riminder/hrflow-connectors/assets/57711045/9dc5543c-5507-4317-ad23-c1702153a972 width=90% height=100% >
</p>

## 🧠 Artificial Intelligence capabilities:
- Extract, Structure, and Categorize Talent & Workforce data
- Search, Score, and Match Profiles & Jobs with our APIs and AI Widgets (**Matching Custom Tab in Bullhorn**)

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/217298819-29d43799-422d-48f4-8995-272d0af66cbe.gif width=90% height=100% >
</p>

# 🔌 Connector Actions
<p align="center">

| Action | Description |
| ------- | ----------- |
| [**Push profile**](docs/push_profile.md) | Writes a profile from Hrflow.ai Source to Bullhorn via the API |
| [**Pull job list**](docs/pull_job_list.md) | Retrieves jobs from Bullhorn and writes them to Hrflow.ai Board |
| [**Pull resume attachment list**](docs/pull_resume_attachment_list.md) | retrieves profiles attachments from Bullhorn and Parses them and sends them to Hrflow.ai source |
| [**Pull profile list**](docs/pull_profile_list.md) | Retrieves profiles from Bullhorn and writes them to Hrflow.ai source |
| [**Push application**](docs/push_application.md) | Retrieves profiles from Hrflow.ai and writes their applications to the Bullhorn source |


</p>|



# 🐍 Quick Start Examples

To make sure you can successfully run the latest versions of the example scripts, you have to **install the package from PyPi**.


To browse the examples of actions corresponding to released versions of 🤗 this connector, you just need to import the module like this :

<p align="center">
<image src=https://user-images.githubusercontent.com/57711045/216126235-03319722-c10b-460d-b19d-0e4240fe652c.png width=90% height=100% >
</p>


Once the connector module is imported, you can leverage all the different actions that it offers.

For more code details checkout connector code


# 🔗 Useful Links

- 📄Visit [Bullhorn](https://www.bullhorn.com/) to learn more.
- 💻 [Connector code](https://github.com/Riminder/hrflow-connectors/tree/master/src/hrflow_connectors/connectors/bullhorn) on our Github.


# 👏 Special Thanks
- 💻 HrFlow.ai : [Daniel ROSA](https://github.com/DanielRosa73) - Software Engineer
- 🤝 Bullhorn : Arne LOOTEN - Partner Manager
